pub struct Arguments {
    pub hexadecimal: bool,
    pub mode: u8,
    pub program_name: String,
    pub reverse_characters: bool,
    pub value_to_convert: String,
}

pub fn parse_direction(args: &mut impl Iterator<Item = String>, opts: &Arguments, current_arg: String) -> Result<u8, String>{
    let mut rvalue = opts.mode;
    let direction = match args.next() {
        None => return Err(format!("argument for {} was not provided", current_arg)),
        Some(e) => e,
    };
    match direction.as_str() {
        "row"            => { rvalue &= !(1 << 1) ; rvalue &= !(1 << 2); }
        "row-reverse"    => { rvalue |= 1 << 1    ; rvalue &= !(1 << 2); }
        "column"         => { rvalue &= !(1 << 1) ; rvalue |= 1 << 2   ; }
        "column-reverse" => { rvalue |= 1 << 1    ; rvalue |= 1 << 2   ; }
        _ => return Err(
            format!("invalid direction \"{}\" provided for {}", direction, current_arg)
        )
    };
    return Ok(rvalue);
}

pub fn parse_wrap(args: &mut impl Iterator<Item = String>, opts: &Arguments, current_arg: String) -> Result<u8, String>{
    let mut rvalue = opts.mode;
    let wrap = match args.next() {
        None => return Err(format!("argument for {} was not provided", current_arg)),
        Some(e) => e,
    };
    match wrap.as_str() {
        "normal"  => rvalue &= !(1 << 0),
        "reverse" => rvalue |= 1 << 0,
        _ => return Err(
            format!("invalid wrap \"{}\" provided for {}", wrap, current_arg)
        )
    };
    return Ok(rvalue);
}
